**To delete a password for an IAM user**

The following ``delete-login-profile`` command deletes the password for the IAM user named ``Bob``::

  aws iam delete-login-profile --user-name Bob

For more information, see `Managing Passwords`_ in the *Using IAM* guide.

.. _`Managing Passwords`: http://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingLogins.html


